@@ -1,4 +1,4 @@
-# Time-stamp: <2013-03-05 16:53:49 Tao Liu>
+# Time-stamp: <2013-04-15 14:09:06 Tao Liu>
 
 """Module Description
 
@@ -100,8 +100,12 @@ def opt_validate ( options ):
         sys.exit(1)
 
     # refine_peaks, call_summits can't be combined with --broad
-    if options.broad and (options.refine_peaks or options.call_summits):
-        logging.error("--broad can't be combined with --refine-peaks or --call-summits!")
+    #if options.broad and (options.refine_peaks or options.call_summits):
+    #    logging.error("--broad can't be combined with --refine-peaks or --call-summits!")
+    #    sys.exit(1)
+
+    if options.broad and options.call_summits:
+        logging.error("--broad can't be combined with --call-summits!")
         sys.exit(1)
 
     if options.pvalue:
@@ -127,8 +131,8 @@ def opt_validate ( options ):
     # output filenames
     options.peakxls = options.name+"_peaks.xls"
     options.peakbed = options.name+"_peaks.bed"
-    options.peakNarrowPeak = options.name+"_peaks.encodePeak"
-    options.peakBroadPeak = options.name+"_broad_peaks.bed"
+    options.peakNarrowPeak = options.name+"_peaks.narrowPeak"
+    options.peakBroadPeak = options.name+"_broad_peaks.bed12"
     options.summitbed = options.name+"_summits.bed"
     options.zwig_tr = options.name+"_treat"
     options.zwig_ctl= options.name+"_control"
@@ -170,6 +174,8 @@ def opt_validate ( options ):
 
     if options.downsample:
         options.argtxt += "# Larger dataset will be randomly sampled towards smaller dataset.\n"
+        if options.seed >= 0:
+            options.argtxt += "# Random seed has been set as: %d\n" % options.seed
     else:
         if options.tolarge:
             options.argtxt += "# Smaller dataset will be scaled towards larger dataset.\n"
@@ -186,8 +192,8 @@ def opt_validate ( options ):
     else:
         options.argtxt += "# Broad region calling is off\n"
 
-    if options.refine_peaks:
-        options.argtxt += "# Refining peak for read balance is on\n"
+    #if options.refine_peaks:
+    #    options.argtxt += "# Refining peak for read balance is on\n"
     if options.call_summits:
         options.argtxt += "# Searching for subpeak summits is on\n"
 
